==> jc-1.4.0.tar.gz: soot/jimple/toolkits/annotation/tags/ArrayNullCheckTag.h <==
// public class soot.jimple.toolkits.annotation.tags.ArrayNullCheckTag

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class eb270b1fb8850b78 soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag_H_
#define _JC_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$sub_refs	_jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$sub_refs;
typedef struct _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$sub_nonrefs	_jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$refs	_jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$refs;
typedef struct _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$nonrefs	_jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$object	_jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$object;

typedef struct _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$fields_struct	_jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$fields_struct;
typedef const struct _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$vmethods	_jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$vmethods;
typedef const struct _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$vtable	_jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$vtable;
typedef const struct _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$vtype	_jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$vtype;

// Class fields structure
struct _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$fields_struct {
	struct _jc_java_lang_String$object	*NAME;
};
extern _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$fields_struct _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$class_fields;

// Constructors
extern void _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$object *);
extern void _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$method$_init$3f3083d4dc5dd7b4(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$object *, jbyte);

// Virtual methods
extern jbyte _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$method$accumulate$0f9c4e8949a1326c(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$object *, jbyte);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$object *);
extern _jc_byte_array *_jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$method$getValue$824c7561d2f47329(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$method_info$accumulate$0f9c4e8949a1326c;
extern _jc_method _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$method_info$getValue$824c7561d2f47329;
extern _jc_method _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$vmethods {
	jbyte	(*accumulate$0f9c4e8949a1326c)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$object *, jbyte);
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$object *);
	_jc_byte_array	*(*getValue$824c7561d2f47329)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$vmethods	soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag;
};

// Vtype
struct _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$refs {
    _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$sub_refs	soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$sub_nonrefs {
	jbyte	value;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$sub_nonrefs	soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$object {
	_jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$vtype	*vtype;
	_jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$vtype _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$class_object;

#endif	/* _JC_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/annotation/tags/ArrayNullCheckTag.h <==
// public class soot.jimple.toolkits.annotation.tags.ArrayNullCheckTag

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class eb270b1fb8850b78 soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag_H_
#define _JC_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$sub_refs	_jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$sub_refs;
typedef struct _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$sub_nonrefs	_jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$refs	_jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$refs;
typedef struct _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$nonrefs	_jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$object	_jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$object;

typedef struct _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$fields_struct	_jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$fields_struct;
typedef const struct _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$vmethods	_jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$vmethods;
typedef const struct _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$vtable	_jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$vtable;
typedef const struct _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$vtype	_jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$vtype;

// Class fields structure
struct _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$fields_struct {
	struct _jc_java_lang_String$object	*NAME;
};
extern _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$fields_struct _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$class_fields;

// Constructors
extern void _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$method$_init$3f3083d4dc5dd7b4(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$object *, jbyte) _JC_JCNI_ATTR;

// Virtual methods
extern jbyte _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$method$accumulate$0f9c4e8949a1326c(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$object *, jbyte) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$object *) _JC_JCNI_ATTR;
extern _jc_byte_array *_jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$method$getValue$824c7561d2f47329(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$method_info$accumulate$0f9c4e8949a1326c;
extern _jc_method _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$method_info$getValue$824c7561d2f47329;
extern _jc_method _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$vmethods {
	jbyte	(*accumulate$0f9c4e8949a1326c)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$object *, jbyte) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$object *) _JC_JCNI_ATTR;
	_jc_byte_array	*(*getValue$824c7561d2f47329)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$vmethods	soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag;
};

// Vtype
struct _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$refs {
    _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$sub_refs	soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$sub_nonrefs {
	jbyte	value;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$sub_nonrefs	soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$object {
	_jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$vtype	*vtype;
	_jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$vtype _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag$class_object;

#endif	/* _JC_soot_jimple_toolkits_annotation_tags_ArrayNullCheckTag_H_ */
